2021-08-27 Version: 2.0.6
- Support ClientToken for ValidateTemplate.

2021-07-20 Version: 2.0.5
- GetStack supports resource progress.
- ValidateTemplate supports Outputs.

2021-03-31 Version: 2.0.4
- Generated python 2019-09-10 for ROS.

2021-01-22 Version: 2.0.3
- Generated python 2019-09-10 for ROS.

2021-01-22 Version: 1.3.0
- Generated python 2019-09-10 for ROS.

2021-01-21 Version: 1.2.2
- Generated python 2019-09-10 for ROS.

2021-01-21 Version: 1.2.1
- The creation and update APIs of the stack supports specifing tags, and the query and list APIs supports obtaining tags.

2021-01-20 Version: 2.0.2
- AMP Version Change.

2021-01-20 Version: 2.0.1
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-12-17 Version: 1.2.0
- Support template version.
- Support to share template.
- Stack and StackGroup support TemplateId and TemplateVersion.
- Add GenerateTemplatePolicy which can generate RAM policy by template.

